"use client";

import { ReactElement } from "react";
import { StorageIcon } from "@/app/components/icon/storage-icon";
import { Stat } from "@/app/components/stat";
import useWebSocket from "react-use-websocket";

type Stat = {
  id: string;
  displayName: string;
  icon: ReactElement;
};

const stats: Stat[] = [
  {
    id: "totalRequests",
    displayName: "Total Requests",
    icon: <StorageIcon />,
  },
];

export function Stats(): ReactElement {
  const { lastMessage, readyState } = useWebSocket("wss://api.mcutils.xyz/websocket/metrics");
  const metrics = lastMessage !== null ? JSON.parse(lastMessage.data).metrics : undefined;

  return (
    <>
      {stats.map((stat, index) => {
        const value = metrics ? metrics[stat.id] : "???";

        return <Stat key={index} title={stat.displayName} value={value} icon={stat.icon} />;
      })}
    </>
  );
}
